|
From: Markus R. <god...@us...> - 2009-07-29 15:35:50
|
Module: performous
Branch: master
Commit: 1d9cf906230165eaf353c25aeadcd7ccf5ed6753
Author: Markus Raab <un...@ma...>
Date: Mon Jul 27 15:30:21 2009 +0200
more doc
---
game/highscore.hh | 18 +++++++++++++++++-
game/screen_players.cc | 3 ++-
game/screen_sing.cc | 1 +
3 files changed, 20 insertions(+), 2 deletions(-)
diff --git a/game/screen_players.cc b/game/screen_players.cc
index fb424a9..6281c0c 100644
--- a/game/screen_players.cc
+++ b/game/screen_players.cc
@@ -88,7 +88,8 @@ void ScreenPlayers::manageEvent(SDL_Event event) {
} else {
m_search.text.clear();
m_players.setFilter("");
- // enter the next highscore
+ // add all players which reach highscore because if score is very near or same it might be
+ // frustrating for second one that he cannot enter, so better go for next one...
}
}
// The rest are only available when there are songs available
diff --git a/game/screen_sing.cc b/game/screen_sing.cc
index 5614597..765ef96 100644
--- a/game/screen_sing.cc
+++ b/game/screen_sing.cc
@@ -72,6 +72,7 @@ void ScreenSing::manageEvent(SDL_Event event) {
if (m_score_window.get())
{
// TODO: multiple loading...
+ // TODO: make it possible to switch of highscore through configuration
HighScore hi(m_song->path, "High.sco");
try {
hi.load();
|
diff --git a/game/highscore.hh b/game/highscore.hh
index 7f186da..6d1c2ad 100644
--- a/game/highscore.hh
+++ b/game/highscore.hh
@@ -32,7 +32,18 @@ struct HighScoreItem {
}
};
-/**HighScore loads and saves a list of HighScoreItems.*/
+/**HighScore loads and saves a list of HighScoreItems.
+
+ Format of highscore is compatible with Ultrastar.
+
+ Name of File: High.sco
+ @code
+#PLAYER0:name
+#SCORE0:1234
+ @endcode
+ Then the same thing for PLAYER/SCORE with other numbers up to 9.
+ Finally, you need to have a line that says only "E".
+ */
class HighScore {
public:
HighScore (std::string const& path_, std::string const& filename_);
@@ -44,6 +55,11 @@ class HighScore {
void getInfo (std::ostream & os);
/**Check if you reached a new highscore.
+
+ You must be in TOP 3 to enter the highscore list.
+ This is because it will take forever to fill all 9.
+ And people refuse to enter their names if they are not close to the top.
+
@param score is a value between 0 and 10000
values below 500 will lead to returning false
@return true if the score make it into the top.